<?php
/**
 * SPDX-FileCopyrightText: 2024 Sascha Nitsch (grumpydeveloper) https://contentnation.net/@grumpydevelop
 * SPDX-License-Identifier: GPL-3.0-or-later
 *
 * @author Sascha Nitsch (grumpydeveloper)
 **/

 namespace Federator\Api;

/**
 * /@username or /users/ handlers
 */
class FedUsers implements APIInterface
{
    /**
     * main instance
     *
     * @var \Federator\Main $main
     */
    private $main;

    /**
     * response from sub-calls
     *
     * @var string $response
     */
    private $response;

    /**
     * constructor
     *
     * @param \Federator\Main $main main instance
     */
    public function __construct($main)
    {
        $this->main = $main;
    }

    /**
     * run given url path
     *
     * @param array<string> $paths path array split by /
     * @param \Federator\Data\User|false $user user who is calling us @unused-param
     * @return bool true on success
     */
    public function exec($paths, $user)
    {
        $method = $_SERVER["REQUEST_METHOD"];
        switch ($method) {
            case 'GET':
                switch (sizeof($paths)) {
                    case 2:
                        // /users/username or /@username
                        return $this->returnUserProfile($paths[1]);
                }
                break;
        }
        $this->main->setResponseCode(404);
        return false;
    }


    /**
     * return user profile
     *
     * @param string $_name
     * @eturn boolean true on success
     */
    private function returnUserProfile($_name)
    {
        $user = \Federator\DIO\User::getUserByName(
            $this->main->getDatabase(),
            $_name,
            $this->main->getConnector(),
            $this->main->getCache()
        );
        if ($user === false || $user->id === null) {
            throw new \Federator\Exceptions\FileNotFound();
        }
        $data = [
            'iconMediaType' => $user->iconMediaType,
            'iconURL' => $user->iconURL,
            'imageMediaType' => $user->imageMediaType,
            'imageURL' => $user->imageURL,
            'fqdn' => $_SERVER['SERVER_NAME'],
            'name' => $user->name,
            'username' => $user->id,
            'publickey' => str_replace("\n", "\\n", $user->publicKey),
            'registered' => gmdate('Y-m-d\TH:i:s\Z', $user->registered), // 2021-03-25T00:00:00Z
            'summary' => $user->summary,
            'type' => $user->type
        ];
        $this->response = $this->main->renderTemplate('user.json', $data);
        return true;
    }
    /**
     * set response
     *
     * @param string $response response to set
     * @return void
     */
    public function setResponse($response)
    {
        $this->response = $response;
    }

    /**
     * get internal represenation as json string
     * @return string json string or html
     */
    public function toJson()
    {
        return $this->response;
    }
}
